@@ -147,7 +147,11 @@ above.
 
     default_grading_model = get_grading_model()
 
-    default_software_projects = get_software_projects(include_projects=['fin-model-course', 'finstmt', 'sensitivity'])
+    software_project_names = ['fin-model-course', 'py-finstmt', 'sensitivity']
+    default_software_projects = get_software_projects(
+        include_projects=software_project_names,
+        order=software_project_names,
+    )
 
     data = dict(
         title='Financial Modeling',
