@@ -6,9 +6,17 @@ from pyexlatex.logic.format.and_join import join_with_commas_and_and_output_list
 from derobertis_cv.models.skill import SkillModel, first_word_untouched_rest_capitalized, \
     first_word_untouched_rest_lower, first_word_untouched_rest_title
 
+
+def _recursive_sort_skills(skills: List[SkillModel], **sort_kwargs):
+    skills.sort(**sort_kwargs)
+    for skill in skills:
+        _recursive_sort_skills(skill.children, **sort_kwargs)
+
+
 PROGRAMMING_SKILL = SkillModel('Programming', 5)
 SOFTWARE_ARCHITECTURE_SKILL = SkillModel('software architecture', 4)
 OS_SKILL = SkillModel('operating systems', 3)
+HARDWARE_SKILL = SkillModel('computer hardware', 3)
 SOFTWARE_DEVELOPMENT_SKILL = SkillModel('software development', 5, parents=(PROGRAMMING_SKILL,))
 FRONTEND_SKILL = SkillModel('Front-end Development', 4, parents=(SOFTWARE_DEVELOPMENT_SKILL, SOFTWARE_ARCHITECTURE_SKILL))
 BACKEND_SKILL = SkillModel('Back-end Development', 5, parents=(SOFTWARE_DEVELOPMENT_SKILL, SOFTWARE_ARCHITECTURE_SKILL))
@@ -43,6 +51,10 @@ SERVER_ADMIN_SKILL = SkillModel('server administration', 4, parents=(DEV_OPS_SKI
 NETWORKING_SKILL = SkillModel('networking', 3, parents=(DEV_OPS_SKILL,))
 MONITORING_SKILL = SkillModel('application monitoring', 2, parents=(DEV_OPS_SKILL,))
 CI_SKILL = SkillModel('CI/CD', 4, parents=(DEV_OPS_SKILL,), flexible_case=False)
+SEO_SKILL = SkillModel('SEO', 2, parents=(WEB_DEVELOPMENT_SKILL,), flexible_case=False)
+CMS_SKILL = SkillModel('CMS', 4, parents=(WEB_DEVELOPMENT_SKILL,), flexible_case=False)
+MIGRATIONS_SKILL = SkillModel('migrations', 5, parents=(DATABASE_SKILL,))
+IDE_SKILL = SkillModel('IDEs', 4, parents=(PROGRAMMING_SKILL,))
 
 
 LINUX_SKILL = SkillModel('Linux', 4, parents=(OS_SKILL,), flexible_case=False)
@@ -146,6 +158,11 @@ _SKILLS: List[SkillModel] = [
     JS_SKILL,
     TS_SKILL,
     AWS_SKILL,
+    SEO_SKILL,
+    CMS_SKILL,
+    MIGRATIONS_SKILL,
+    HARDWARE_SKILL,
+    IDE_SKILL,
     SkillModel('SQL', 4, parents=(DATABASE_SKILL,), flexible_case=False),
     SkillModel('Redis', 4, parents=(DATABASE_SKILL,), flexible_case=False),
     SkillModel('Angular', 4, parents=FE_TS_WEB_FRAMEWORK_SKILLS, flexible_case=False),
@@ -169,6 +186,11 @@ _SKILLS: List[SkillModel] = [
     SkillModel('CloudWatch', 3, parents=(AWS_SKILL, MONITORING_SKILL), flexible_case=False),
     SkillModel('CloudFormation', 2, parents=(AWS_SKILL, SERVER_ADMIN_SKILL, NETWORKING_SKILL), flexible_case=False),
 
+    SkillModel('JIRA', 4, parents=(WEB_DEVELOPMENT_SKILL, COLLABORATION_SKILL), flexible_case=False),
+
+    SkillModel('PyCharm', 4, parents=(IDE_SKILL,), flexible_case=False),
+    SkillModel('VS Code', 4, parents=(IDE_SKILL,), flexible_case=False),
+
     SkillModel(
         'empirical research', 5, parents=(RESEARCH_SKILL, STATISTICS_SKILL, DATA_ANALYSIS_SKILL, DATA_MUNGING_SKILL)
     ),
@@ -190,11 +212,12 @@ _SKILLS: List[SkillModel] = [
     SkillModel('SciPy', 3, parents=DS_FRAMEWORK_SKILLS + (DATA_ANALYSIS_SKILL,), flexible_case=False),
     SkillModel('SymPy', 4, parents=DS_FRAMEWORK_SKILLS + (DATA_ANALYSIS_SKILL,), flexible_case=False),
     SkillModel('scikit-learn', 3, parents=DS_FRAMEWORK_SKILLS + (MACHINE_LEARNING_SKILL, DATA_ANALYSIS_SKILL), flexible_case=False),
-    SkillModel('Jupyter', 4, parents=DS_FRAMEWORK_SKILLS, flexible_case=False),
+    SkillModel('Jupyter', 4, parents=DS_FRAMEWORK_SKILLS + (IDE_SKILL,), flexible_case=False),
     SkillModel('Matplotlib', 4, parents=DS_FRAMEWORK_SKILLS + (PLOTTING_SKILL,), flexible_case=False),
     SkillModel('HoloViews', 3, parents=DS_FRAMEWORK_SKILLS + (PLOTTING_SKILL,), flexible_case=False),
 
     SkillModel('Flask', 5, parents=BE_WEB_FRAMEWORK_SKILLS, flexible_case=False),
+    SkillModel('Django', 2, parents=BE_WEB_FRAMEWORK_SKILLS, flexible_case=False),
     SkillModel('SQLAlchemy', 5, parents=BE_WEB_FRAMEWORK_SKILLS, flexible_case=False),
 
     SkillModel('Celery', 4, parents=ASYNC_FRAMEWORK_SKILLS, flexible_case=False),
@@ -208,6 +231,9 @@ _SKILLS: List[SkillModel] = [
     SkillModel('Dash', 2, parents=FULL_STACK_WEB_PYTHON_FRAMEWORK_SKILLS, flexible_case=False),
     SkillModel('Sphinx', 4, parents=FULL_STACK_WEB_PYTHON_FRAMEWORK_SKILLS + (DOCUMENTATION_SKILL,), flexible_case=False),
 
+    SkillModel('Pelican', 3, parents=FULL_STACK_WEB_PYTHON_FRAMEWORK_SKILLS + (CMS_SKILL,), flexible_case=False),
+    SkillModel('Wagtail', 2, parents=FULL_STACK_WEB_PYTHON_FRAMEWORK_SKILLS + (CMS_SKILL,), flexible_case=False),
+
     SkillModel('Jinja2', 4, parents=(FRAMEWORK_SKILL, PYTHON_SKILL, TEMPLATING_SKILL), flexible_case=False),
     SkillModel('pytest', 4, parents=(FRAMEWORK_SKILL, PYTHON_SKILL, TESTING_SKILL), flexible_case=False),
 
@@ -218,7 +244,7 @@ _SKILLS: List[SkillModel] = [
     SkillModel('fire', 3, parents=(FRAMEWORK_SKILL, PYTHON_SKILL, CLI_SKILL), flexible_case=False),
 ]
 
-_SKILLS.sort(key=lambda skill: skill.level, reverse=True)
+_recursive_sort_skills(_SKILLS, key=lambda skill: skill.level, reverse=True)
 
 SKILLS: Dict[str, SkillModel] = {skill.to_lower_case_str(): skill for skill in _SKILLS}
 
@@ -241,8 +267,10 @@ def get_skills(exclude_skills: Optional[Sequence[str]] = None,
         use_skills = [skill for skill in skills if skill.to_lower_case_str() not in child_excluded_skill_names]
 
     if order is not None:
-        use_skills.sort(
-            key=lambda skill: order.index(skill.to_lower_case_str()) if skill.to_lower_case_str() in order else 100000  # type: ignore
+        _recursive_sort_skills(
+            use_skills,
+            key=lambda skill: order.index(skill.to_lower_case_str())
+            if skill.to_lower_case_str() in order else 100000 - skill.level  # type: ignore
         )
 
     return use_skills
